import type { Region } from "@valapi/lib";
import { AuthRequest } from "./AuthRequest";
import type { PromiseResponse, Response, RequestConfig } from "./AuthRequest";
import { AuthInstance } from "./AuthInstance";
import type { AuthUserInfo } from "./AuthInstance";
interface ErrorResponse {
    type: "error";
    error: string;
    country: string;
}
type UriResponse = ErrorResponse | {
    type: "response";
    response: {
        mode: string;
        parameters: {
            uri: string;
        };
    };
    country: string;
};
export interface hCaptcha {
    sitekey: string;
    rqdata: string;
}
export interface LoginData {
    username: string;
    password: string;
    captcha: string;
}
export interface Config extends Omit<RequestConfig, "cookie"> {
    user?: AuthUserInfo;
    sdk?: string;
}
export declare class Auth extends AuthInstance {
    readonly request: AuthRequest;
    readonly sdk: string;
    constructor(config?: Config);
    private hasCookie;
    private analyzeCookie;
    private analyzeResponseCookie;
    captcha(): Promise<hCaptcha>;
    protected authorize<T>(): PromiseResponse<T>;
    reauthorize(): Promise<void>;
    login(data: LoginData): Promise<void>;
    multifactor(loginCode: number): Promise<void>;
    protected loginTokenization(loginToken: string): Promise<void>;
    protected uriTokenization(uriResponse: Response<UriResponse>): Promise<void>;
    protected uriParamsTokenization(uri: string): void;
    protected entitlementsTokenization(): Promise<void>;
    regionTokenization(): Promise<Region.ID>;
}
export {};
