"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AuthInstance = void 0;
const tough_cookie_1 = require("tough-cookie");
const lib_1 = require("@valapi/lib");
class AuthInstance {
    get isAuthenticated() {
        return new Date() < this.expirationDate && Boolean(this.access_token) && Boolean(this.entitlements_token);
    }
    constructor(user) {
        this.cookie = new tough_cookie_1.CookieJar();
        this.isMultifactor = false;
        this.login_token = "";
        this.access_token = "";
        this.id_token = "";
        this.session_state = "";
        this.entitlements_token = "";
        this.subject = "";
        this.expirationDate = new Date(-1);
        if (!user) {
            return;
        }
        this.cookie = tough_cookie_1.CookieJar.deserializeSync(user.cookie);
        this.isMultifactor = user.isMultifactor;
        this.login_token = user.login_token;
        this.access_token = user.access_token;
        this.id_token = user.id_token;
        this.session_state = user.session_state;
        this.entitlements_token = user.entitlements_token;
        this.getTokenInfo();
    }
    getTokenInfo() {
        if (!this.access_token) {
            return;
        }
        const parseToken = lib_1.ValEncryption.decryptJson(this.access_token.split(".")[1]);
        this.subject = parseToken.sub;
        this.expirationDate = new Date(parseToken.exp * 1000);
    }
    toJSON() {
        return {
            cookie: this.cookie.serializeSync(),
            isMultifactor: this.isMultifactor,
            login_token: this.login_token,
            access_token: this.access_token,
            id_token: this.id_token,
            session_state: this.session_state,
            entitlements_token: this.entitlements_token
        };
    }
}
exports.AuthInstance = AuthInstance;
