"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AuthRequest = void 0;
const tslib_1 = require("tslib");
const node_tls_1 = require("node:tls");
const axios_1 = tslib_1.__importStar(require("axios"));
const http_1 = require("http-cookie-agent/http");
const selfsigned = tslib_1.__importStar(require("selfsigned"));
const lib_1 = require("@valapi/lib");
class AuthRequest {
    constructor(config) {
        var _a;
        const __config = Object.assign({
            build: "91.0.2.1870.3774", // GET https://valorant-api.com/v1/version["data"]["riotClientBuild"]
            version: "release-09.00-shipping-28-2628993", // GET https://valorant-api.com/v1/version["data"]["riotClientVersion"]
            platform: {
                platformType: "PC",
                platformOS: "Windows",
                platformOSVersion: "10.0.19043.1.256.64bit",
                platformChipset: "Unknown"
            },
            axiosConfig: {
                withCredentials: true
            }
        }, config);
        this.defaultAxiosConfig = __config.axiosConfig;
        this.certificate =
            (_a = __config.certificate) !== null && _a !== void 0 ? _a : selfsigned.generate([], {
                days: 30,
                pkcs7: true,
                clientCertificate: true,
                clientCertificateCN: lib_1.ValEncryption.randomString(16)
            });
        this.headers = new axios_1.AxiosHeaders()
            .setContentType("application/json")
            .setAccept("application/json")
            .setUserAgent(AuthRequest.newUserAgent(__config.build, "rso-auth"))
            .set({
            "X-Riot-ClientVersion": __config.version,
            "X-Riot-ClientPlatform": lib_1.ValEncryption.encryptJson(__config.platform)
        });
        const ctx_options = {
            cert: this.certificate.cert,
            sigalgs: [
                "ecdsa_secp256r1_sha256",
                "rsa_pss_rsae_sha256",
                "rsa_pkcs1_sha256",
                "ecdsa_secp384r1_sha384",
                "rsa_pss_rsae_sha384",
                "rsa_pkcs1_sha384",
                "rsa_pss_rsae_sha512",
                "rsa_pkcs1_sha512",
                "rsa_pkcs1_sha1"
            ].join(":"),
            ciphers: [
                "TLS_AES_128_GCM_SHA256",
                "TLS_CHACHA20_POLY1305_SHA256",
                "TLS_AES_256_GCM_SHA384",
                "TLS_AES_128_CCM_SHA256",
                "TLS_AES_128_CCM_8_SHA256",
                "TLS_ECDHE_ECDSA_WITH_CHACHA20_POLY1305_SHA256"
            ].join(":"),
            honorCipherOrder: true,
            key: this.certificate.private,
            maxVersion: "TLSv1.3",
            minVersion: "TLSv1.2"
        };
        this.agent = new http_1.HttpsCookieAgent(Object.assign(Object.assign(Object.assign({}, __config.agentConfig), ctx_options), {
            // #TcpSocketConnectOpts
            keepAlive: true,
            // #CommonConnectionOptions
            requestCert: false,
            secureContext: (0, node_tls_1.createSecureContext)(ctx_options),
            rejectUnauthorized: false,
            // #CookieAgentOptions
            cookies: {
                jar: __config.cookie
            }
        }));
    }
    get axiosConfig() {
        return Object.assign(Object.assign({}, this.defaultAxiosConfig), {
            httpsAgent: this.agent,
            headers: Object.assign(Object.assign({}, this.defaultAxiosConfig.headers), this.headers.toJSON())
        });
    }
    static newUserAgent(build, app = "%s", os = "Windows;10;;Professional, x64") {
        return `RiotClient/${build} ${app} (${os})`;
    }
    create() {
        return axios_1.default.create(this.axiosConfig);
    }
    get(url) {
        return axios_1.default.get(url, this.axiosConfig);
    }
    post(url, data = {}) {
        return axios_1.default.post(url, data, this.axiosConfig);
    }
    put(url, data = {}) {
        return axios_1.default.put(url, data, this.axiosConfig);
    }
    delete(url) {
        return axios_1.default.delete(url, this.axiosConfig);
    }
}
exports.AuthRequest = AuthRequest;
